@@ -158,7 +158,7 @@ class OvsHost(linux.LinuxDevice):
         self.cmd('ovs-ctl start')
         self.cmd('systemctl start docker')
 
-        cmd = "ls -l /sys/class/net/ | egrep -v 'virtual|total' | awk -F / '{print $NF}'"
+        cmd = "ls -l /sys/class/net/ | egrep -v 'virtual|total' | awk '{print $9}'"
         self.nics = self.cmd(cmd, log_level = 4).split()
         self.log("host's phicial nics: %s" %(self.nics))
 
@@ -216,7 +216,9 @@ class OvsHost(linux.LinuxDevice):
 
         '''
         ip = kwargs.pop("ip", []) #get the ip configuration of the bridge
+        # Process the ports and bonds specially:
         ports = kwargs.pop("port", []) # get the ports list
+        bonds = kwargs.pop("bond", {}) # get the ports list
         # Create the kwargs
         command = 'ovs-vsctl --may-exist add-br %s' %(name)
         if kwargs:
@@ -232,12 +234,6 @@ class OvsHost(linux.LinuxDevice):
         if self.cmd("ovs-vsctl get-fail-mode %s" %(name)).strip() == "secure":
             self.ofctl_add_flow(name, "priority=0,actions=drop")
 
-        if ip:
-            # Configure the ip address for the address for route
-            self.cmd('ip address add %s dev %s' %(ip, name))
-            self.cmd('ip link set %s up' %(name))
-            self.cmd('ovs-appctl ovs/route/add %s %s' %(ip, name))
-
         # Add self-port if any, it's port = xxx, or *args,
         ports = ports if (isinstance(ports, list)) else [ports]
         ports = ports if (not args) else ports.extend(args)
@@ -247,6 +243,26 @@ class OvsHost(linux.LinuxDevice):
                 self.takeover_interface(name, p["name"])
             else:
                 self.add_port(name, p)
+        if bonds:
+            self.add_bond(name, bonds["name"], *bonds["port"])
+
+        if ip:
+            # Configure the ip address for the address for route
+            for p in ports:
+                self.cmd("ip addr flush dev %s" %(p))
+            self.cmd('ip link set %s up' %(name))
+            self.cmd('ip address add %s dev %s' %(ip, name))
+            #self.cmd('ovs-appctl ovs/route/add %s %s' %(ip, name))
+
+    def add_bond (self, bridge_name, bond_name, *args, **kwargs):
+        '''
+        Add bond.
+        '''
+        for p in args:
+            self.cmd("ip addr flush dev %s" %(p))
+        cmd = "ovs-vsctl add-bond %s %s " %(bridge_name, bond_name)
+        cmd += " ".join(args)
+        self.cmd(cmd)
 
     def add_port (self, bridge_name, kwargs):
         '''
@@ -497,14 +513,17 @@ class OvsHost(linux.LinuxDevice):
         if self.cmd("ovs-vsctl get-fail-mode %s" %(bridge_name)).strip() != "secure":
             #Don't need configure vtep explicitly in standalone mode.
             return
+
+        str_vtep = (isinstance(vtep, dict)) and vtep["name"] or vtep
+        vxlan_ofport = self.ovs_get_interface(str_vtep, "ofport")
         for arg in args:
-            ipaddr = ipaddress.ip_interface(arg["ip"]).ip
-            vxlan_port = self.ovs_get_interface(vtep["name"], "ofport")
+            str_ip = (isinstance(arg, dict)) and arg["ip"] or arg
+            ipaddr = ipaddress.ip_interface(str_ip).ip
             self.ofctl_add_flow(bridge_name,
                     "priority=1000,arp,arp_tpa=%s,actions=output:%s"
-                    %(ipaddr, vxlan_port),
+                    %(ipaddr, vxlan_ofport),
                     "priority=1000,ip,nw_dst=%s,actions=output:%s" 
-                    %(ipaddr, vxlan_port))
+                    %(ipaddr, vxlan_ofport))
 
     def add_gateway (self, bridge_name, gw, *args):
         '''
